@@ -94,6 +94,8 @@ static const char *copyright[] = {
 #include <FL/Fl_Pixmap.H>
 #include <FL/Fl_Image.H>
 
+#include "XmlRpcClient.h"
+
 using namespace std;
 
 std::string rx_buffer;
@@ -838,7 +840,7 @@ void addfile(std::string xmtfname, void *rx, bool useCompression, \
 	int use_comp_on_file = 0;
 	int use_forced_comp_on_file = 0;
 
-	if(rx > 0 && !rAmp->rx_completed()) {
+	if(rx != NULL && !rAmp->rx_completed()) {
 		fl_alert2("Only completed files can be transfered");
 		return;
 	}
@@ -934,7 +936,7 @@ void addfile(std::string xmtfname, void *rx, bool useCompression, \
 
 	LOG_INFO("File added to transmit queue: %s", xmtfname.c_str());
 
-	if(rx > 0) {
+	if(rx != NULL) {
 		cAmp *rAmp = (cAmp *) rx;
 		int xfrBlockSize = rAmp->rx_blocksize_int();
 
@@ -1271,9 +1273,9 @@ void auto_load_tx_queue_from_list(void)
 	strncpy(path, cPtr,	FILENAME_MAX - 1);
 
 	if(size < 1)
-		strncpy(path, "./", 2);
+		strcpy(path, "./");
 	else if(path[size - 1] != '/')
-		strncat(path, "/", 1);
+		strcat(path, "/");
 
 	while(1) {
 
@@ -2649,7 +2651,7 @@ int parse_args(int argc, char **argv, int& idx)
 
 
 	if (strcasecmp(argv[idx], "--version") == 0) {
-		printf("Version: "VERSION"\n");
+		printf("Version: " VERSION "\n");
 		exit (0);
 	}
 	return 0;
@@ -2668,8 +2670,17 @@ void exit_main(Fl_Widget *w)
 /** ********************************************************
  *
  ***********************************************************/
-int main(int argc, char *argv[])
+static std::string pname = "";
+
+int main (int argc, char *argv[])
 {
+	pname = argv[0];
+	size_t pn = pname.rfind("/");
+	if (pn != std::string::npos) pname.erase(0, pn + 1);
+	pn = pname.rfind("\\");
+	if (pn != std::string::npos) pname.erase(0, pn + 1);
+	XmlRpc::set_pname(pname);
+
 	NBEMS_dir.clear();
 	{
 		string appname = argv[0];
@@ -2812,7 +2823,7 @@ int main(int argc, char *argv[])
 		perror("pthread_create: ztimer watch dog not started");
 	}
 
-	ztimer((void *)true);
+	Fl::add_timeout(0, ztimer, (void *)true);
 
 	if(progStatus.auto_load_queue) {
 		auto_load_tx_queue();
